@@ -202,16 +202,7 @@ class MidiEventStream(object):
                             yield self.NOTE_OFF, chn, e.m_pitch, e.m_velocity
                     for e in track[tpos]['OtherEvents']:
                         if isinstance(e, SetPatchEvent):
-                            # Let us check if it is necessary to alloc a
-                            # channel before we do so. It might have been
-                            # allocated before.
-                            try:
-                                chn = ch_dev.get_channel_for_patch(e.m_patch)
-                                track_instrument[idx] = e.m_patch
-                            except:
-                                chn = ch_dev.alloc_channel(e.m_patch)
-                                track_instrument[idx] = e.m_patch
-                                yield self.SET_PATCH, chn, e.m_patch
+                            track_instrument[idx] = e.m_patch
                         elif isinstance(e, TempoEvent):
                             yield self.TEMPO, e.m_bpm, e.m_notelen
                         else:
@@ -241,6 +232,8 @@ class MidiEventStream(object):
         """
         filename -- a string naming the file to write the generated midi file to.
                     Will overwrite a existing file.
+        appendstrings -- a list of additional MidiEventStreams to append to
+                    the midi file.
         """
         v = []
         notelen = 0
@@ -271,6 +264,38 @@ class MidiEventStream(object):
         v = v + mfutils.mf_end_of_track()
         mfutils.write_vect(f, v)
         f.close()
+    def str_repr(self, details=0):
+        v = []
+        v.append([])
+        for e in self:
+            if e[0] == self.TEMPO:
+                v[-1].append("t%s/%s" % (e[1], e[2]))
+            elif e[0] == self.NOTE_ON:
+                if e[1] == 9:
+                    v[-1].append("P%s" % e[2])
+                else:
+                    if details == 0:
+                        v[-1].append("n%s" % e[2])
+                    elif details == 1:
+                        v[-1].append("n%s:%s" % (e[1], e[2]))
+            elif e[0] == self.NOTE_OFF:
+                v[-1].append("o%s" % e[2])
+            elif e[0] == self.SET_PATCH:
+                v[-1].append("p%i:%i" % (e[1], e[2]))
+            elif e[0] == self.NOTELEN_TIME:
+                v[-1].append("d%i/%i" % (e[1].m_num, e[1].m_den))
+                v.append([])
+        retval = []
+        for x in v:
+            n = [e for e in x if e.startswith('t')]
+            if n:
+                retval.append(" ".join([e for e in x if e.startswith('t')]))
+            for typ in ('p', 'o', 'P', 'n', 'd'):
+                n = [e for e in x if e.startswith(typ)]
+                if n:
+                    n.sort()
+                    retval.append(" ".join(n))
+        return " ".join(retval)
 
 
 class Track:
@@ -284,6 +309,18 @@ class Track:
     def txtdump(self):
         for event in self.m_v:
             print event
+    def str_repr(self):
+        retval = []
+        for e in self.m_v:
+            if isinstance(e, SetPatchEvent):
+                retval.append('p%i' % e.m_patch)
+            elif isinstance(e, NoteOnEvent):
+                retval.append('n%i' % e.m_pitch)
+            elif isinstance(e, NoteOffEvent):
+                retval.append('o%i' % e.m_pitch)
+            elif isinstance(e, Delay):
+                retval.append('d%i/%i' % (e.m_duration.m_num, e.m_duration.m_den))
+        return " ".join(retval)
     def __init__(self):
         self.m_v = []
     def start_note(self, pitch, vel):
@@ -370,7 +407,9 @@ class Track:
                 event.m_pitch = new
     def calculate_event_times(self):
         """
-        Set the variable m_time on each Event.
+        Set the variable m_time on each Event. Well actually we don't set
+        it on the Delay events because events of that type does not generate
+        any events when generating music.
         """
         pos = Rat(0, 1)
         for e in self.m_v:
