@@ -526,7 +526,7 @@ class Gui(abstract.LessonbasedGui):
         for exceptions.
         """
         fontsize = self.get_int('config/feta_font_size=20')
-        if self.m_t.m_P.get_question()['music'].m_musictype == 'chord':
+        if isinstance(self.m_t.m_P.get_question()['music'], lessonfile.Chord):
             clef = mpd.select_clef(self.m_t.m_P.get_music_as_notename_string('music'))
             self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music_as_notename_string('music')), fontsize)
         else:
