@@ -20,7 +20,7 @@ import gobject
 import random
 
 import gu, utils
-from multipleintervalconfigwidget import IntervalCheckBox
+from multipleintervalconfigwidget import nIntervalCheckBox
 import mpd, mpd.musicdisplayer, soundcard
 import abstract, const
 import lessonfile
@@ -160,10 +160,10 @@ class Gui(abstract.Gui):
         hbox.pack_start(gtk.Label(_("First interval:")), False,
                         padding=gu.PAD_SMALL)
         self.g_rdbs = [pack_rdbs(hbox, self.update_first)]
-        self.g_first_interval_up = IntervalCheckBox(self.m_exname,
+        self.g_first_interval_up = nIntervalCheckBox(self.m_exname,
                                                          'first_interval_up')
         self.g_intervalconfig_box.pack_start(self.g_first_interval_up, False)
-        self.g_first_interval_down = IntervalCheckBox(self.m_exname,
+        self.g_first_interval_down = nIntervalCheckBox(self.m_exname,
                              'first_interval_down')
         self.g_intervalconfig_box.pack_start(self.g_first_interval_down, False)
         #----------
@@ -171,10 +171,10 @@ class Gui(abstract.Gui):
         hbox.pack_start(gtk.Label(_("Last interval:")), False,
                         padding=gu.PAD_SMALL)
         self.g_rdbs.append (pack_rdbs(hbox, self.update_last))
-        self.g_last_interval_up = IntervalCheckBox(self.m_exname,
+        self.g_last_interval_up = nIntervalCheckBox(self.m_exname,
                      'last_interval_up')
         self.g_intervalconfig_box.pack_start(self.g_last_interval_up, False)
-        self.g_last_interval_down = IntervalCheckBox(self.m_exname,
+        self.g_last_interval_down = nIntervalCheckBox(self.m_exname,
                         'last_interval_down')
         self.g_intervalconfig_box.pack_start(self.g_last_interval_down, False)
         #------------
