@@ -42,6 +42,7 @@ assignmentlist peek: 'NAME' '='
 # som tester de to neste token.
 
 import sys
+import weakref
 import i18n
 
 import os, os.path
@@ -136,10 +137,6 @@ class Question(dict):
         if "C-name" in self:
             return self["C-name"]
         return "[no name]"
-    def get_music(self, varname='music'):
-        return self['m_lessonfile'].get_mpd_music_string(self, varname)
-    def is_transposable(question):
-        return question['music'].m_musictype in ('chord', 'satb', 'voice', 'rvoice')
 
 
 class DataparserException(Exception):
@@ -158,6 +155,16 @@ class NameLookupException(DataparserException):
         self.m_token = parser._lexer.m_tokens[bad_pos]
         self.m_nonwrapped_text = parser._lexer.get_err_context(bad_pos)
 
+class WrongArgumentCount(DataparserException):
+    def __init__(self, parser, bad_pos):
+        DataparserException.__init__(self,
+            _("Wrong argument count in line %(line)i of file \"%(filename)s\":") % {
+                'line': parser._lexer.m_tokens[bad_pos][TOKEN_LINENO],
+                'filename': parser.m_filename})
+        # This variable is only used by the module test code.
+        self.m_token = parser._lexer.m_tokens[bad_pos]
+        self.m_nonwrapped_text = parser._lexer.get_err_context(bad_pos)
+
 
 class DataparserSyntaxError(DataparserException):
     def __init__(self, parser, bad_pos, expect):
@@ -188,13 +195,16 @@ class UnableToTokenizeException(DataparserException):
         DataparserException.__init__(self,
             _('Unable to tokenize line %(lineno)i of the file "%(filename)s"') % {
                 'lineno': lineno + 1,
-                'filename': lexer.m_parser.m_filename})
+                'filename': lexer.m_parser().m_filename})
         self.m_nonwrapped_text = lexer.get_tokenize_err_context()
 
 
 class Lexer:
     def __init__(self, src, parser):
-        self.m_parser = parser
+        if parser:
+            self.m_parser = weakref.ref(parser)
+        else:
+            self.m_parser = parser
         r = re.compile("#.*?coding\s*[:=]\s*([\w_.-]+)")
         m = r.match(src)
         if m:
@@ -275,7 +285,7 @@ class Lexer:
             return self.m_tokens[self.pos-1][TOKEN_STRING]
         else:
             # Tested in TestLexer.test_scan
-            raise DataparserSyntaxError(self.m_parser, self.pos,
+            raise DataparserSyntaxError(self.m_parser(), self.pos,
                 _("Token \"%(nottoken)s\" not found, found \"%(foundtoken)s\" of type %(type)s.") % {
                     'nottoken': t,
                     'foundtoken': self.m_tokens[self.pos][TOKEN_STRING],
@@ -484,6 +494,8 @@ class Dataparser:
                 return self.functions[name](*arglist)
             except KeyError:
                 raise NameLookupException(self, npos)
+            except TypeError:
+                raise WrongArgumentCount(self, npos)
     def block(self):
         """block: NAME "{" assignmentlist "}" """
         name = self._lexer.scan_any()
