@@ -15,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
+import time
 import gtk
 import gobject
 import re
@@ -409,11 +410,11 @@ def dialog_yesno(text, parent=None):
     m.destroy()
     return ret == gtk.RESPONSE_YES
 
-def dialog_ok(text, parent=None, secondary_text=None):
+def dialog_ok(text, parent=None, secondary_text=None, msgtype=gtk.MESSAGE_INFO):
     """"
     Return the gtk.RESPONSE_XXXX returned by .run()
     """
-    m = gtk.MessageDialog(parent, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
+    m = gtk.MessageDialog(parent, gtk.DIALOG_MODAL, msgtype,
             gtk.BUTTONS_OK, text)
     if secondary_text:
         m.format_secondary_text(secondary_text)
@@ -481,3 +482,181 @@ def create_rhythm_image(rhythm):
     im.show()
     return im
 
+
+class EditorDialogBase(gtk.Window):
+    # Classes inheriting from this must define self.savedir
+    instance_counter = 0
+    def __init__(self):
+        gtk.Window.__init__(self)
+        self.m_filename = None
+        self.m_instance_number = EditorDialogBase.instance_counter
+        EditorDialogBase.instance_counter += 1
+        self.connect('delete_event', self.on_delete_event)
+        self.g_ui_manager = gtk.UIManager()
+        self.g_actiongroup = gtk.ActionGroup('TrainingSetActions')
+        self.g_actiongroup.add_actions([
+         ('Close', gtk.STOCK_CLOSE, None, None, None, self.close_window),
+         ('Save', gtk.STOCK_SAVE, None, None, None, self.on_save),
+         ('SaveAs', gtk.STOCK_SAVE_AS, None, None, None, self.on_save_as),
+         ('New', gtk.STOCK_NEW, None, None, None, self.new_file),
+         ('Open', gtk.STOCK_OPEN, None, None, None, self.on_open),
+         ('Help', gtk.STOCK_HELP, None, None, None, self.on_show_help),
+        ])
+    def _get_a_filename(self):
+        """
+        Return a file name. UntitledN (where N is an integer) if we
+        have to real name.
+        """
+        if not self.m_filename:
+            return _("Untitled%s") % EditorDialogBase.instance_counter
+        return self.m_filename
+    def close_window(self, *w):
+        if not self.m_changed:
+            self.destroy()
+            return
+        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
+            gtk.MESSAGE_WARNING, gtk.BUTTONS_NONE,
+            _("Save changes to \"%s\" before closing?") % self._get_a_filename())
+        t = time.time() - self.m_savetime
+        if t < 60:
+            msg = _("If you don't save, changes from the past %i seconds will be permanently lost.") % int(time.time() - self.m_savetime)
+        else:
+            msg = _("If you don't save, changes from the past %i minutes will be permanently lost.") % int((time.time() - self.m_savetime) / 60.0)
+        m.format_secondary_text(msg)
+        m.add_button(_("_Close without Saving"), gtk.RESPONSE_CLOSE)
+        m.add_button("gtk-cancel", gtk.RESPONSE_CANCEL)
+        m.add_button("gtk-save", gtk.RESPONSE_OK)
+        m.set_default_response(gtk.RESPONSE_OK)
+        r = m.run()
+        m.destroy()
+        if r == gtk.RESPONSE_CLOSE:
+            self.destroy()
+        elif r in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
+            return
+        else:
+            assert r == gtk.RESPONSE_OK
+            self.on_save()
+            self.destroy()
+    def on_delete_event(self, *ignore):
+        self.close_window()
+        return True
+    def on_open(self, widget):
+        """
+        Open a FileChooserDialog and select a file.
+        Load into this editor window if it is empty and unused,
+        if not load into a new one.
+
+        This method will catch exceptions raised while loading the file
+        and display a dialog. Then it will destroy any newly created
+        dialog.
+        """
+        dialog = gtk.FileChooserDialog(None, self,
+            gtk.FILE_CHOOSER_ACTION_OPEN,
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+             gtk.STOCK_OK, gtk.RESPONSE_OK))
+        dialog.set_current_folder(self.savedir)
+        ret = dialog.run()
+        if ret == gtk.RESPONSE_OK:
+            try:
+                if (not self.m_filename) and (not self.m_changed):
+                    win = self.new_file()
+                    win.load_file(dialog.get_filename())
+                    win.set_title(win.m_filename)
+                    self.destroy()
+                else:
+                    win = self.new_file()
+                    win.load_file(dialog.get_filename())
+                    win.set_title(win.m_filename)
+            except Exception, e:
+                # Since we catch all sorts of exceptions here, we don't have
+                # to do handle string to int conversion in
+                # PractiseSheet.parse_file. Just let int() raise ValueException
+                # if the string in not an integer.
+                self.m_app.m_ui.display_exception_message(e, __file__)
+                win.destroy()
+        dialog.destroy()
+    def on_save_as(self, widget):
+        """
+        Return True if the file was saved, False if not.
+        """
+        dialog = gtk.FileChooserDialog(_("Save As..."), self,
+            gtk.FILE_CHOOSER_ACTION_SAVE,
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+             gtk.STOCK_OK, gtk.RESPONSE_OK))
+        dialog.set_default_response(gtk.RESPONSE_OK)
+        if not os.path.exists(self.savedir):
+            try:
+                os.mkdir(self.savedir)
+            except OSError, e:
+                pass
+        # if self.m_filename is set to a real filename, we will
+        # display the folder where that file exists. If not, we will
+        # use .solfege/trainingsets
+        if os.path.dirname(self._get_a_filename()):
+            dialog.set_current_folder(os.path.dirname(self._get_a_filename()))
+        else:
+            dialog.set_current_folder(self.savedir)
+        if dialog.get_current_folder() == os.path.dirname(self._get_a_filename()):
+            dialog.set_current_name(os.path.basename(self._get_a_filename()))
+        else:
+            dialog.set_current_name(self._get_a_filename())
+        while 1:
+            ret = dialog.run()
+            if ret == gtk.RESPONSE_OK:
+                if os.path.exists(dialog.get_filename()):
+                    if not dialog_yesno(_("File exists. Overwrite?")):
+                        continue
+                try:
+                    self.m_filename = dialog.get_filename()
+                    self.save()
+                    self.set_title(self.m_filename)
+                except IOError, e:
+                    dialog_ok(_("Error saving file"), self, str(e), gtk.MESSAGE_ERROR)
+                    dialog.destroy()
+                    return False
+                break
+            elif ret in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
+                break
+        dialog.destroy()
+        return ret == gtk.RESPONSE_OK
+    def on_save(self, widget=None):
+        """
+        Return True if the file was saved, False if not.
+        """
+        if not self.m_filename:
+            return self.on_save_as(widget)
+        else:
+            self.save()
+            return True
+    def new_file(self, action=None):
+        """
+        Return the new dialog window.
+        """
+        m = self.__class__(self.m_app)
+        m.show_all()
+        return m
+    def select_empty_directory(self, title):
+        msg = _("Select an empty directory, since we want to fill it with files.")
+        dialog = gtk.FileChooserDialog(title,
+            self, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+             gtk.STOCK_OK, gtk.RESPONSE_OK))
+        label = gtk.Label(msg)
+        label.show()
+        dialog.vbox.pack_start(label, False, False)
+        while 1:
+            res = dialog.run()
+            if res in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
+                dialog.destroy()
+                return
+            elif res == gtk.RESPONSE_OK:
+                if os.listdir(dialog.get_filename()):
+                    msg_dlg = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
+                        gtk.MESSAGE_INFO, gtk.BUTTONS_OK, msg)
+                    msg_dlg.run()
+                    msg_dlg.destroy()
+                else:
+                    break
+        ret = dialog.get_filename()
+        dialog.destroy()
+        return ret
