@@ -27,7 +27,7 @@ class Teacher(idbyname.Teacher):
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
-        self.m_P.play_question_as_choral(self.m_P.get_question())
+        self.m_P.play_question()
 
 
 class Gui(abstract.LessonbasedGui):
