@@ -26,7 +26,7 @@ import cfg
 import gu
 import lessonfilegui
 from gpath import Path
-import gethomedir
+import filesystem
 
 class Menu(dict):
     def new_from_name(name):
@@ -503,7 +503,7 @@ class LessonFileDialogCommon(gtk.Dialog):
         self.g_module.set_text(self.g_liststore.get(iter, 4)[0])
         self.g_topics_vbox.foreach(lambda w: w.destroy())
         for s in self.m_tree.iterate_topics_for_id(
-                self.g_liststore.get(iter, 2)):
+                self.g_liststore.get(iter, 2)[0]):
             label = gtk.Label(s)
             label.set_alignment(0.0, 0.5)
             label.show()
@@ -701,11 +701,11 @@ class Window(gtk.Window):
         if self.m_app.m_options.debug:
             self.m_trees.append(('solfege', 'debugtree.txt', os.path.join(os.getcwd(), 'debugtree.txt')))
         try:
-            v = os.listdir(os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees"))
+            v = os.listdir(os.path.join(filesystem.app_data(), "learningtrees"))
         except OSError:
             v = []
         for fn in v:
-            self.m_trees.append(('user', fn, os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees", fn)))
+            self.m_trees.append(('user', fn, os.path.join(filesystem.app_data(), "learningtrees", fn)))
         self.g_trees_liststore.clear()
         for t, fn, txt in self.m_trees:
             self.g_trees_liststore.append((txt,))
@@ -813,14 +813,14 @@ class Window(gtk.Window):
                 if path or (not filename):
                     self.g_filename_description.set_text(donot_str)
                     self.g_filename_description.show()
-                elif os.path.exists(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename)):
+                elif os.path.exists(os.path.join(filesystem.app_data(), 'learningtrees', filename)):
                     self.g_filename_description.set_text(_("The file already exists."))
                     self.g_filename_description.show()
                 else:
                     try:
-                        if not os.path.exists(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees')):
-                            os.makedirs(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees'))
-                        f = open(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename), 'w')
+                        if not os.path.exists(os.path.join(filesystem.app_data(), 'learningtrees')):
+                            os.makedirs(os.path.join(filesystem.app_data(), 'learningtrees'))
+                        f = open(os.path.join(filesystem.app_data(), 'learningtrees', filename), 'w')
                         f.write("""
 [ # toplevel list
   2, # learning tree file format version
@@ -1147,7 +1147,7 @@ class Window(gtk.Window):
             do_del = True
             if self.m_tree.get_use_count(del_id) == 1:
                 if self.m_tree.get_dep_use_count(del_id) > 0:
-                    do_del = gu.dialog_yesno(_("Some lessons depend on this lesson. Delete anyway, and update the dependency list for lessons that depend on this lesson?"), self)
+                    do_del = gu.dialog_yesno(_("Lessons depend on this lesson. Delete anyway, and update the dependency list for lessons that depend on this lesson?"), self)
                     if do_del:
                         self.m_tree.remove_all_deps_of(del_id)
             if do_del:
@@ -1182,7 +1182,7 @@ class Window(gtk.Window):
             self._load_file(filename)
         else:
             assert place == 'user'
-            self._load_file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
+            self._load_file(os.path.join(filesystem.app_data(), 'learningtrees', filename))
         self.set_trees_combo(place, filename)
         # 
         if place == 'solfege':
