@@ -24,6 +24,7 @@ import sys
 import os
 import time
 import urllib
+import shutil
 
 # The sets module was added in python 2.3. So we will use that module
 # if we are running python 2.3, and the builtin set if we are using
@@ -203,9 +204,10 @@ import rhythmtapping2
 
 import learning_tree_editor
 from trainingsetdlg import TrainingSetDialog
+from practisesheetdlg import PractiseSheetDialog
 from docviewer import DocViewer
 from helpbrowser import HelpBrowser
-import gethomedir
+import filesystem
 
 class MusicViewerWindow(gtk.Dialog):
     def __init__(self, app):
@@ -326,7 +328,7 @@ class MainWin(App, cfg.ConfigUtils):
                 self.m_tree.load(filename)
             else:
                 assert loc == 'user'
-                self.m_tree.load(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
+                self.m_tree.load(os.path.join(filesystem.app_data(), 'learningtrees', filename))
         except IOError:
             if splash_win:
                 splash_win.hide()
@@ -351,6 +353,8 @@ class MainWin(App, cfg.ConfigUtils):
           ('TestsMenu', None, _("_Tests")),
           ('ExportTrainingSet', None, _('New training set editor window'), None, None,
             self.new_training_set_editor),
+          ('EditPractiseSheet', None, _('Ear training test printout editor'), None, None,
+            self.new_practisesheet_editor),
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
           ('HelpMenu', None, _('_Help')),
@@ -388,7 +392,7 @@ class MainWin(App, cfg.ConfigUtils):
         if self.m_learning_trees_merge_id:
             self.g_ui_manager.remove_ui(self.m_learning_trees_merge_id)
         try:
-            v = os.listdir(os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees"))
+            v = os.listdir(os.path.join(filesystem.app_data(), "learningtrees"))
         except OSError:
             v = []
         if not self.m_app.m_options.debug and not v:
@@ -651,6 +655,29 @@ GNU General Public License for more details.""")
                 splash_win.destroy()
                 splash_win = None
             self.m_app.display_sound_init_error_message(self.m_app.m_sound_init_exception)
+        # MIGRATION 3.9.0
+        if sys.platform == "win32" \
+            and os.path.exists(os.path.join(filesystem.get_home_dir(), "lessonfiles")) \
+            and not os.path.exists(filesystem.user_lessonfiles()):
+                if splash_win:
+                    splash_win.hide()
+                do_move = gu.dialog_yesno(_('In Solfege 3.9.0, the location where Solfege look for lesson files you have created was changed. The files has to be moved from "%(old)s" and into the folder "%(gnu)s" in your "%(doc)s" folder.\nMay I move the files automatically for you now?' % {
+                    'doc':  os.path.split(os.path.split(filesystem.user_data())[0])[1],
+                    'gnu':  os.path.join(filesystem.appname, 'lessonfiles'),
+                    'old': os.path.join(filesystem.get_home_dir(), "lessonfiles"),
+                  }), parent=self)
+                if do_move:
+                    try:
+                        os.makedirs(filesystem.user_data())
+                        shutil.copytree(os.path.join(filesystem.get_home_dir(), "lessonfiles"),
+                                        os.path.join(filesystem.user_data(), "lessonfiles"))
+                    except (OSError, shutil.Error), e:
+                        gu.dialog_ok(_("Error while copying directory:\n%s" % e))
+                    else:
+                        gu.dialog_ok(_("Files copied. The old files has been left behind. Please delete them when you have verified that all files was copied correctly."))
+
+                if splash_win:
+                    splash_win.show()
     def activate_exercise(self, module, urlobj=None):
         if self.m_viewer:
             self.box_dict[self.m_viewer].hide()
@@ -754,6 +781,9 @@ GNU General Public License for more details.""")
     def new_training_set_editor(self, widget):
         dlg = TrainingSetDialog(self.m_app)
         dlg.show_all()
+    def new_practisesheet_editor(self, widget):
+        dlg = PractiseSheetDialog(self.m_app)
+        dlg.show_all()
 
 
 import locale
