@@ -15,40 +15,63 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gu
+import gtk
+import gobject
+import gu
 import const
 import cfg
 
-class IntervalCheckBox(gtk.HBox, cfg.ConfigUtils):
-    def __init__(self, exname, varname):
+class IntervalCheckBox(gtk.HBox):
+    """
+    Emit 'value-changed' if the state of an interval has changed.
+    """
+    max_interval = 16 # Major decim
+    def __init__(self):
         gtk.HBox.__init__(self)
+        self.checkbox_dict = {}
+        for x in range(1, self.max_interval):
+            self.checkbox_dict[x] = c \
+                = gtk.ToggleButton(const.short_interval_name[x])
+            c.set_data('interval', x)
+            c.connect('toggled', self.on_toggle)
+            c.show()
+            self.pack_start(c)
+    def on_toggle(self, _o):
+        self.emit('value-changed', self.get_value())
+    def get_value(self):
+        """
+        Return a list with the integer value for the intervals
+        that are active.
+        """
+        return [x for x in self.checkbox_dict.keys() \
+                if self.checkbox_dict[x].get_active()]
+    def set_value(self, v):
+        """
+        Set the state of the intervals.
+        v is a list of integers representing the intervals that are
+        active.
+        """
+        for key, btn in self.checkbox_dict.items():
+            self.checkbox_dict[key].set_active(key in v)
+        return
+
+
+class nIntervalCheckBox(IntervalCheckBox, cfg.ConfigUtils):
+    def __init__(self, exname, varname):
+        IntervalCheckBox.__init__(self)
         cfg.ConfigUtils.__init__(self, exname)
         self.m_varname = varname
         intervals = self.get_list(self.m_varname)
         if not intervals:
             intervals = range(1, 17)
             self.set_list(varname, intervals)
-        self.checkbox_dict = {}
-        for x in range(1, 17):
-            self.checkbox_dict[x] = c = gtk.ToggleButton(const.short_interval_name[x])
-            c.set_data('interval', x)
-            if x in intervals:
-                c.set_active(True)
-            c.connect('toggled', self.on_toggle)
-            c.show()
-            self.pack_start(c)
+        self.set_value(intervals)
         self.add_watch(self.m_varname, self._watch_cb)
     def _watch_cb(self, name):
-        V = self.get_list(self.m_varname)
-        for k in range(1, 17):
-            self.checkbox_dict[k].set_active(k in V)
+        self.set_value(self.get_list(self.m_varname))
     def on_toggle(self, _o):
-        v = []
-        keys = self.checkbox_dict.keys()
-        for k in keys:
-            if self.checkbox_dict[k].get_active():
-                v.append(k)
-        self.set_list(self.m_varname, v)
+        IntervalCheckBox.on_toggle(self, _o)
+        self.set_list(self.m_varname, self.get_value())
 
 
 class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
