@@ -42,13 +42,14 @@ class Teacher(abstract.Teacher):
             qvar = 'rhythm'
         else:
             qvar = 'music'
-        musictype = self.m_P.get_question()['music'].m_musictype
+        is_rhythm = isinstance(self.m_P.get_question()['music'],
+                               lessonfile.Rhythm)
         lexer = mpd.parser.Lexer(self.m_P.get_question()[qvar].m_musicdata)
         x = len(lexer.m_string)
         retval = []
         while lexer.m_idx < x:
             toc, toc_data = lexer.get()
-            if musictype == 'rhythm':
+            if is_rhythm == 'rhythm':
                 if toc_data.m_pitch.get_octave_notename() == 'd':
                     continue
                 if toc_data.m_pitch.get_octave_notename() != 'c':
