@@ -22,14 +22,13 @@
 import sys
 import time, os, pickle
 import utils
-import gethomedir
+import filesystem
 
 # version 1, the first version was introduced with Solfege 2.0
 # version 2 was introduced in the newxercisesetup changes
 statistics_version = 2
 
-STATISTICS_SAVE_DIR = os.path.join(gethomedir.get_home_dir(), '.solfege',
-    'statistics')
+STATISTICS_SAVE_DIR = os.path.join(filesystem.app_data(), 'statistics')
 
 if not os.path.exists(STATISTICS_SAVE_DIR):
     if not os.path.exists(STATISTICS_SAVE_DIR):
@@ -209,14 +208,14 @@ class LessonStatistics(AbstractStatistics):
         before calling this function.
         """
         #FIXME nuke STATISTICS_SAVE_DIR??
-        self.m_savepath = os.path.join(gethomedir.get_home_dir(), '.solfege',
+        self.m_savepath = os.path.join(filesystem.app_data(),
                 'testresults', self.m_t.m_P.header.lesson_id)
     def exit_test_mode(self):
         """
         We assume that the program has saved and emptied the data dict
         before calling this function.
         """
-        self.m_savepath = os.path.join(gethomedir.get_home_dir(), '.solfege',
+        self.m_savepath = os.path.join(filesystem.app_data(),
                 'statistics', self.m_t.m_P.header.lesson_id)
     def get_label_style(self):
         return self.m_t.m_P.header.labelformat
