@@ -20,7 +20,7 @@ import gtk
 import os
 import time
 import pickle
-from gethomedir import get_home_dir
+import filesystem
 import gu
 import configureoutput
 from dataparser import Dataparser, DataparserException
@@ -30,8 +30,7 @@ import lessonfile
 # The definition of a training set will be stored in a file in the
 # ~/.solfege/trainingsets
 
-class TrainingSetDialog(gtk.Window):
-    instance_counter = 0
+class TrainingSetDialog(gu.EditorDialogBase):
     fileformat_version = 1
     STORE_LESSON_ID = 0
     STORE_TITLE = 1
@@ -39,10 +38,8 @@ class TrainingSetDialog(gtk.Window):
     STORE_REPEAT = 3
     STORE_DELAY = 4
     def __init__(self, app):
-        gtk.Window.__init__(self)
-        TrainingSetDialog.instance_counter += 1
-        self.savedir = os.path.join(get_home_dir(), ".solfege", "trainingsets")
-        self.connect('delete_event', self.on_delete_event)
+        gu.EditorDialogBase.__init__(self)
+        self.savedir = os.path.join(filesystem.user_data(), "trainingsets")
         self.set_default_size(800, 300)
         self.m_app = app
         # This VBox will have 2 parts.
@@ -102,7 +99,7 @@ class TrainingSetDialog(gtk.Window):
         self.init_empty_file()
         self.show_all()
     def on_treeview_cursor_changed(self, treeview):
-        self.g_ui_manager.get_widget("/ExportToolbar/SetRemove").set_sensitive(True)
+        self.g_ui_manager.get_widget("/ExportToolbar/Remove").set_sensitive(True)
     def on_count_edited(self, renderer, path, text):
         self._edit_col(2, path, text)
     def on_repeat_edited(self, renderer, path, text):
@@ -121,19 +118,19 @@ class TrainingSetDialog(gtk.Window):
             iter = self.g_liststore.get_iter_from_string(path)
             self.g_liststore.set_value(iter, col_num, i)
     def on_remove_lesson_clicked(self, *w):
-        path, column = self.g_treeview.get_cursor()
-        assert path
-        iter = self.g_liststore.get_iter(path)
-        if iter:
-            if self.g_liststore.remove(iter):
-                self.g_treeview.set_cursor(self.g_liststore.get_path(iter))
-            elif path[0] > 0:
-                self.g_treeview.set_cursor((path[0]-1,))
-            else:
-                self.g_ui_manager.get_widget("/ExportToolbar/SetRemove").set_sensitive(False)
-        else:
-            print "NOt delete because not iter"
-        print "ITER:", iter
+       path, column = self.g_treeview.get_cursor()
+       assert path
+       iter = self.g_liststore.get_iter(path)
+       if iter:
+           if self.g_liststore.remove(iter):
+               self.g_treeview.set_cursor(self.g_liststore.get_path(iter))
+           elif path[0] > 0:
+               self.g_treeview.set_cursor((path[0]-1,))
+           else:
+               self.g_ui_manager.get_widget("/ExportToolbar/Remove").set_sensitive(False)
+       else:
+           print "NOt delete because not iter"
+       print "ITER:", iter
     def on_add_lesson_clicked(self, button):
         menu = self.create_learning_tree_menu()
         menu.popup(None, None, None, 1, 0)
@@ -234,114 +231,45 @@ class TrainingSetDialog(gtk.Window):
                     sub.hide()
     def init_empty_file(self):
         self.m_changed = False
-        self.m_filename = None
         self.m_savetime = time.time()
         self.set_title(self._get_a_filename())
-        self.g_ui_manager.get_widget("/ExportToolbar/SetRemove").set_sensitive(False)
-    def _get_a_filename(self):
-        """
-        Return a file name. UntitledN (where N is an integer) if we
-        have to real name.
-        """
-        if not self.m_filename:
-            return _("Untitled%s") % TrainingSetDialog.instance_counter
-        return self.m_filename
+        self.g_ui_manager.get_widget("/ExportToolbar/Remove").set_sensitive(False)
     def setup_toolbar(self):
-        self.g_toolbar = gtk.Toolbar()
-        self.g_ui_manager = gtk.UIManager()
-        actiongroup = gtk.ActionGroup('TrainingSetActions')
-        actiongroup.add_actions([
-         ('SetClose', gtk.STOCK_CLOSE, None, None, None, self.close_window),
-         ('SetSave', gtk.STOCK_SAVE, None, None, None, self.on_save),
-         ('SetSaveAs', gtk.STOCK_SAVE_AS, None, None, None, self.on_save_as),
-         ('SetNew', gtk.STOCK_NEW, None, None, None, self.new_file),
-         ('SetOpen', gtk.STOCK_OPEN, None, None, None, self.on_open),
-         ('SetExport', gtk.STOCK_EXECUTE, _("Export"), None, None, self.on_export),
-         ('SetAdd', gtk.STOCK_ADD, None, None, None, self.on_add_lesson_clicked),
-         ('SetRemove', gtk.STOCK_REMOVE, None, None, None, self.on_remove_lesson_clicked),
-         ('SetHelp', gtk.STOCK_HELP, None, None, None, self.on_show_help),
+        self.g_actiongroup.add_actions([
+         ('Export', gtk.STOCK_EXECUTE, _("Export"), None, None, self.on_export),
+         ('Add', gtk.STOCK_ADD, None, None, None, self.on_add_lesson_clicked),
+         ('Remove', gtk.STOCK_REMOVE, None, None, None, self.on_remove_lesson_clicked),
         ])
-        self.g_ui_manager.insert_action_group(actiongroup, 0)
+        self.g_ui_manager.insert_action_group(self.g_actiongroup, 0)
         uixml = """
         <ui>
          <toolbar name='ExportToolbar'>
-          <toolitem action='SetAdd'/>
-          <toolitem action='SetRemove'/>
-          <toolitem action='SetNew'/>
-          <toolitem action='SetOpen'/>
-          <toolitem action='SetSave'/>
-          <toolitem action='SetSaveAs'/>
-          <toolitem action='SetExport'/>
-          <toolitem action='SetClose'/>
-          <toolitem action='SetHelp'/>
+          <toolitem action='Add'/>
+          <toolitem action='Remove'/>
+          <toolitem action='New'/>
+          <toolitem action='Open'/>
+          <toolitem action='Save'/>
+          <toolitem action='SaveAs'/>
+          <toolitem action='Export'/>
+          <toolitem action='Close'/>
+          <toolitem action='Help'/>
          </toolbar>
         </ui>
         """
         self.g_ui_manager.add_ui_from_string(uixml)
         self.g_vbox.pack_start(self.g_ui_manager.get_widget("/ExportToolbar"), False)
         self.g_ui_manager.get_widget("/ExportToolbar").set_style(gtk.TOOLBAR_BOTH)
-        hbox = gtk.HBox()
-        hbox.set_spacing(8)
-        self.g_vbox.pack_start(hbox, False)
     def on_show_help(self, widget):
         self.m_app.handle_href("trainingset-editor.html")
-    def on_delete_event(self, *ignore):
-        self.close_window()
-        return True
-    def close_window(self, *w):
-        if not self.m_changed:
-            self.destroy()
-            return
-        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
-            gtk.MESSAGE_WARNING, gtk.BUTTONS_NONE,
-            _("Save changes to \"%s\" before closing?") % self._get_a_filename())
-        t = time.time() - self.m_savetime
-        if t < 60:
-            msg = _("If you don't save, changes from the past %i seconds will be permanently lost.") % int(time.time() - self.m_savetime)
-        else:
-            msg = _("If you don't save, changes from the past %i minutes will be permanently lost.") % int((time.time() - self.m_savetime) / 60.0)
-        m.format_secondary_text(msg)
-        m.add_button(_("_Close without Saving"), gtk.RESPONSE_CLOSE)
-        m.add_button("gtk-cancel", gtk.RESPONSE_CANCEL)
-        m.add_button("gtk-save", gtk.RESPONSE_OK)
-        m.set_default_response(gtk.RESPONSE_OK)
-        r = m.run()
-        m.destroy()
-        if r == gtk.RESPONSE_CLOSE:
-            self.destroy()
-        elif r in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
-            return
-        else:
-            assert r == gtk.RESPONSE_OK
-            self.on_save()
-            self.destroy()
     def get_trainingset_filenames(self):
         #FIXME we need to know 100% sure that we will get
         #unicode strings from this method
         try:
-            return os.listdir(os.path.join(get_home_dir(),
-                                       ".solfege", "trainingsets"))
+            return os.listdir(os.path.join(filesystem.user_data(), "trainingsets"))
         except OSError, e:
             if e.errno != 2:
                 print "warning: errno != 2"
             return []
-    def on_open(self, widget):
-        dialog = gtk.FileChooserDialog(None, self,
-            gtk.FILE_CHOOSER_ACTION_OPEN,
-            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-             gtk.STOCK_OK, gtk.RESPONSE_OK))
-        dialog.set_current_folder(self.savedir)
-        ret = dialog.run()
-        if ret == gtk.RESPONSE_OK:
-            try:
-                if (not self.m_filename) and (not self.m_changed):
-                    self.load_file(dialog.get_filename())
-                else:
-                    win = self.new_file()
-                    win.load_file(dialog.get_filename())
-            except Exception, e:
-                self.m_app.m_ui.display_exception_message(e, __file__)
-        dialog.destroy()
     def load_file(self, filename):
         p = Dataparser({'yes': True, 'no': False}, {})
         p.parse_file(filename)
@@ -360,52 +288,6 @@ class TrainingSetDialog(gtk.Window):
                 lesson['repeat'],
                 lesson['delay']))
         self.set_title(self.m_filename)
-    def on_save_as(self, widget):
-        """
-        Return True if the file was saved, False if not.
-        """
-        dialog = gtk.FileChooserDialog(_("Save As..."), self,
-            gtk.FILE_CHOOSER_ACTION_SAVE,
-            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-             gtk.STOCK_OK, gtk.RESPONSE_OK))
-        dialog.set_default_response(gtk.RESPONSE_OK)
-        if not os.path.exists(self.savedir):
-            try:
-                os.mkdir(self.savedir)
-            except OSError, e:
-                pass
-        # if self.m_filename is set to a real filename, we will
-        # display the folder where that file exists. If not, we will
-        # use .solfege/trainingsets
-        if os.path.dirname(self._get_a_filename()):
-            dialog.set_current_folder(os.path.dirname(self._get_a_filename()))
-        else:
-            dialog.set_current_folder(self.savedir)
-        if dialog.get_current_folder() == os.path.dirname(self._get_a_filename()):
-            dialog.set_current_name(os.path.basename(self._get_a_filename()))
-        else:
-            dialog.set_current_name(self._get_a_filename())
-        ret = dialog.run()
-        if ret == gtk.RESPONSE_OK:
-            try:
-                self.m_filename = dialog.get_filename()
-                self.save()
-                self.set_title(self.m_filename)
-            except IOError, e:
-                gu.dialog_ok(_("Error saving file"), self, str(e))
-                dialog.destroy()
-                return False
-        dialog.destroy()
-        return ret == gtk.RESPONSE_OK
-    def on_save(self, widget=None):
-        """
-        Return True if the file was saved, False if not.
-        """
-        if not self.m_filename:
-            return self.on_save_as(widget)
-        else:
-            self.save()
-            return True
     def save(self):
         """
         Save the file to a file named by self.m_filename
@@ -436,36 +318,11 @@ class TrainingSetDialog(gtk.Window):
         f.close()
         self.m_changed = False
         self.m_savetime = time.time()
-    def new_file(self, action=None):
-        """
-        Return the new dialog window.
-        """
-        m = TrainingSetDialog(self.m_app)
-        m.show_all()
-        return m
     def on_export(self, widget):
-        msg = _("Select an empty directory, since we want to fill it with files.")
-        dialog = gtk.FileChooserDialog(_("Select where to export the files"),
-            self, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-             gtk.STOCK_OK, gtk.RESPONSE_OK))
-        label = gtk.Label(msg)
-        label.show()
-        dialog.vbox.pack_start(label, False, False)
-        while 1:
-            res = dialog.run()
-            if res in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
-                dialog.destroy()
-                return
-            if os.listdir(dialog.get_filename()):
-                msg_dlg = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
-                    gtk.MESSAGE_INFO, gtk.BUTTONS_OK, msg)
-                msg_dlg.run()
-                msg_dlg.destroy()
-            else:
-                break
-        export_to = dialog.get_filename()
-        dialog.destroy()
+        export_to = \
+            self.select_empty_directory(_("Select where to export the files"))
+        if not export_to:
+            return
         progress_dialog = gtk.Dialog(_("Exporting training set"), self,
             0, (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
         progress_dialog.show()
